#!/bin/sh
### BEGIN INIT INFO
# Provides:          laser-app
# Required-Start:    avahi
# Required-Stop:     avahi
# Should-Start:	     $syslog
# Should-Stop:       $syslog
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: IPG Photonics application
# Description:       Marking application for IPG Photonics laser head,
#                    controller, and control software.
### END INIT INFO

[ -f /etc/default/ipg ] && source /etc/default/ipg
[ -r "$SETTINGS_SCRIPT" ] && source $SETTINGS_SCRIPT


PATH=/sbin:/bin:/usr/sbin:/usr/bin

echo -n "$UUSER user: "

if [ ! -f "${MARKDAEMON}" ] ; then
    echo "no daemon ${MARKDAEMON}"
    MARKDAEMON=/home/laser/app-marking-main
fi
if [ ! -f "${MODULE}" ] ; then
    MODULE=/home/laser/mark-drv.ko
fi

# make sure scan-files runs at startup/shutdown in case of incron problems
if [ -x /usr/sbin/scan-files ] ; then
    echo -n "scan-files"

    touch $DELAYREBOOTSENTINEL
    /usr/sbin/scan-files

    echo -n " done."
fi

NAME=marking
DESC="IPG Marking Application"
#OPTS=""
INTERFACE=eth0

case "$1" in
  start)

	### This is a hack; we couldn't run reliably at gigabit speed
        ### until we got the slew rates fixed in March 2016
        if [ ! "${GIGE_SLEW_WORKS}" = "YES" ] ; then
	    ethtool -s  "$INTERFACE" speed 100 duplex full
	fi

	### This is another hack; the port isn't handling multicast reception correctly
	###    The driver is probably setting it up wrong.
	ifconfig "$INTERFACE" allmulti

	[ -x /home/${UUSER}/user-key-setup.sh ] &&
	    su -l -c /home/${UUSER}/user-key-setup.sh ${UUSER}
	[ -r /home/${UUSER}/ipgos.service ] && mv /home/${UUSER}/ipgos.service /etc/avahi/services
	sleep 3

	if [ ! -z "$REBOOTSENTINEL" -a -r "$REBOOTSENTINEL" ] ; then
	    logger "rebooting to complete install"
	    sleep 10
	    reboot
	else
	    rm -f $REBOOTSENTINEL $DELAYREBOOTSENTINEL
	fi
	
	[ "${TURNKEY}" = "YES" ] || exit 0

	/sbin/insmod "$MODULE"
	if [ $? != 0 ] ; then
	    echo "Failed to load $DESC module"
	    exit 1
	fi

	sleep 3

	start-stop-daemon --start -x "$MARKDAEMON" -- $OPTS || exit
	rm -f /etc/nologin*
	echo "$NAME."
	;;

  stop)
	echo -n "Stopping $DESC: "
#	KILLAPPCMD
	start-stop-daemon --stop -x "$MARKDAEMON"
	#rmmod mark-drv
	rm -f /etc/avahi/services/ipgos.service
	echo "$NAME."
	;;
  restart|force-reload)
	echo -n "Restarting $DESC: "
	start-stop-daemon --stop -x "$MARKDAEMON"
	sleep 1
	start-stop-daemon --start -x "$MARKDAEMON" -- $OPTS
	echo "$NAME."
	;;
  *)
	N=/etc/init.d/$NAME
	echo "Usage: $N {start|stop|restart|force-reload}" >&2
	exit 1
	;;
esac

echo " done."

: exit 0
