#!/bin/bash

###
### Initialize ssh keys for the "laser" user to allow for remote access.
###
### The eventual plan is to regenerate at every boot, export to an RFC4716 format key, 
###  and advertise the private key in the service record. Also, jail the user into its
###  own home directory to keep this scheme only partly lame as opposed to entirely so.
###

[ -r /etc/default/ipg ] && source /etc/default/ipg

KEYSTYLE=rsa
SIZE=1024
FILENAME=id_${KEYSTYLE}
USEUSER=$UUSER

if [ "${USEUSER}" != "${USER}" ] ; then
    echo "Please run $0 as user ${USEUSER}"
    exit 1 
fi

cd /home/${USEUSER}/.ssh

### 1: create temporary keys
rm -f id_*
ssh-keygen -t ${KEYSTYLE} -b ${SIZE} -q -f ./${FILENAME} -N ""
cat ${FILENAME}.pub > authorized_keys
chmod 644 authorized_keys

### 2: export temporary keys to RFC4716 format
ssh-keygen -e -m rfc4716 -f ${FILENAME}  > ${FILENAME}.rfc4716
chmod 600 ${FILENAME}.rfc4716

rm -f private_key_file
ln -s ${FILENAME} private_key_file


function write_ipgos_file ()
{
	local larray
	local i

	mapfile -t larray < $1

	i=0

	echo "<?xml version=\"1.0\"?>"
	echo '<!DOCTYPE service-group SYSTEM "avahi-service.dtd">'

	echo '<service-group>'

	echo '    <name replace-wildcards="yes">%h</name>'

	echo '    <service>'

	echo '        <port>22</port>'
	echo '        <type>_ipgos._tcp</type>'

	while [ -n "${larray[${i}]}" ] ; do
	    nextparm="${larray[${i}]}"
	    i=$((i+1))
	    nextarg=KEY${i}=${nextparm}
	    echo -n '    <txt-record>'
	    echo -n "${nextarg}"
	    echo '</txt-record>'
	done

	echo ""
	echo "    <txt-record>username=${UUSER}</txt-record>"
	echo "    <txt-record>version-path=${UPDATE_INPUT_DIR_NAME}</txt-record>"
	echo "    <txt-record>configuration-path=${CONFIG_INPUT_DIR_NAME}</txt-record>"
	echo "    <txt-record>ipaddress-file=${IPADDRESS_FILE_NAME}</txt-record>"
	echo "    <txt-record>hostname-file=${HOSTNAME_FILE_NAME}</txt-record>"
	echo "    <txt-record>probe-port=3333</txt-record>"

	echo '    </service>'
	echo '</service-group>'
}

write_ipgos_file private_key_file > ../${IPGOS_SERVICE_FILE}



